@@ -37,7 +37,7 @@
 
 class promo_tests
 {
-  static public function _get_feu()
+  static public function &_get_feu()
   {
     return cms_utils::get_module('FrontEndUsers');
   }
@@ -49,56 +49,52 @@ class promo_tests
    *
    * @param string coupon code
    * @param promotion Promotion object.
-   * @retursn TRUE if this test does not rely on coupon codes, or if the coupon code matches.  FALSE otherwise.
+   * @return TRUE if this test does not rely on coupon codes, or if the coupon code matches.  FALSE otherwise.
    */
-  static public function test_coupon($coupon,&$promo)
+  static public function test_coupon($coupon,promotion $promo)
   {
     $conditions = $promo->get_conditions();
-    for( $i = 0; $i < count($conditions); $i++ )
-      {
-	$cond =& $conditions[$i];
-	if( $cond->get_cond_type() != PROMOTIONS_COND_COUPON )
-	  continue;
+    $fnd = FALSE;
+    for( $i = 0; $i < count($conditions); $i++ ) {
+      $cond = $conditions[$i];
+      if( $cond->get_cond_type() != PROMOTIONS_COND_COUPON ) continue;
 
-	$data = $cond->get_data();
-	if( strcasecmp($coupon,$data) == 0 )
-	  return TRUE;
+      $fnd = TRUE;
+      $data = $cond->get_data();
+      if( strcasecmp($coupon,$data) == 0 ) return TRUE;
+    }
 
-	break;
-      }
+    if( !$fnd ) return TRUE; // this promition has no coupon dependencies.
 
-    // this promotion is not dependant upon order coupons.
+    // this promotion does not match the supplied coupon.
     return FALSE;
   }
 
 
   /**
-   * Test the promotion to see if the promotion is applicable
-   * to order weight calculations, and if so if the supplied
-   * weight is over or equal to the one specified in the
-   * conditions.
+   * Test the promotion to see if it is subject to a weight condition
+   * and wether the weight supplies matches that condition.
    *
    * @param float weight amount
    * @param promotion Promotion object.
    * @retursn TRUE if this test does not rely on order weight, or if the weight value is over the allowed range.  FALSE otherwise.
    */
-  static public function test_order_weight($weight,&$promo)
+  static public function test_order_weight($weight,promotion $promo)
   {
     if( $weight <= 0.00 ) return FALSE;
 
     $conditions = $promo->get_conditions();
-    for( $i = 0; $i < count($conditions); $i++ )
-      {
-	$cond =& $conditions[$i];
-	if( $cond->get_cond_type() != PROMOTIONS_COND_WEIGHT )
-	  continue;
+    for( $i = 0; $i < count($conditions); $i++ ) {
+      $cond = $conditions[$i];
+      if( $cond->get_cond_type() != PROMOTIONS_COND_WEIGHT )
+	continue;
 
-	$data = $cond->get_data();
-	if( $weight >= $data )
-	  return TRUE;
+      $data = $cond->get_data();
+      if( $weight >= $data )
+	return TRUE;
 
-	break;
-      }
+      break;
+    }
 
     // this promotion is not dependant upon order weights.
     return FALSE;
@@ -121,21 +117,19 @@ class promo_tests
 
     $conditions = $promo->get_conditions();
     $found = false;
-    for( $i = 0; $i < count($conditions); $i++ )
-      {
-	$cond =& $conditions[$i];
-	if( $cond->get_cond_type() != PROMOTIONS_COND_SUBTOTAL )
-	  continue;
+    for( $i = 0; $i < count($conditions); $i++ ) {
+      $cond =& $conditions[$i];
+      if( $cond->get_cond_type() != PROMOTIONS_COND_SUBTOTAL )
+	continue;
 
-	$data = $cond->get_data();
-	if( $subtotal >= $data )
-	  {
-	    return TRUE;
-	  }
-
-	break;
+      $data = $cond->get_data();
+      if( $subtotal >= $data ) {
+	return TRUE;
       }
 
+      break;
+    }
+
     // this promotion is not dependant upon order subtotals.
     return FALSE;
   }
@@ -157,41 +151,37 @@ class promo_tests
     if( !$feu ) return FALSE;
 
     $conditions = $promo->get_conditions();
-    for( $i = 0; $i < count($conditions); $i++ )
-      {
-	$cond =& $conditions[$i];
-	if( $cond->get_cond_type() == PROMOTIONS_COND_FEU )
-	  {
-	    // get member groups as array of group names
-	    $member_of = $feu->GetMemberGroupsArray($feu_uid);
-	    if( !$member_of ) return FALSE;
-	    $member_of = cge_array::extract_field($member_of,'groupid');
+    for( $i = 0; $i < count($conditions); $i++ ) {
+      $cond = $conditions[$i];
+      if( $cond->get_cond_type() == PROMOTIONS_COND_FEU ) {
+	// get member groups as array of group names
+	$member_of = $feu->GetMemberGroupsArray($feu_uid);
+	if( !$member_of ) return FALSE;
+	$member_of = cge_array::extract_field($member_of,'groupid');
 
-	    $tmp = $feu->GetGroupList();
-	    $allgroups = array_flip($tmp);
-	    $member_group_names = array();
-	    foreach( $member_of as $onegid )
-	      {
-		$member_group_names[] = $allgroups[$onegid];
-	      }
+	$tmp = $feu->GetGroupList();
+	$allgroups = array_flip($tmp);
+	$member_group_names = array();
+	foreach( $member_of as $onegid ) {
+	  $member_group_names[] = $allgroups[$onegid];
+	}
 
-	    // get the value from the condition
-	    // as an array of trimmed group names.
-	    $data = explode(',',$cond->get_data());
-	    for( $j = 0; $j < count($data); $j++ )
-	      {
-		$data[$j] = trim($data[$j]);
-	      }
+	// get the value from the condition
+	// as an array of trimmed group names.
+	$data = explode(',',$cond->get_data());
+	for( $j = 0; $j < count($data); $j++ ) {
+	  $data[$j] = trim($data[$j]);
+	}
 
-	    // now do an intersection between member groupo names
-	    // and the data group names.
-	    $res = array_intersect($member_group_names,$data);
-	    if( count($res) ) return TRUE;
+	// now do an intersection between member groupo names
+	// and the data group names.
+	$res = array_intersect($member_group_names,$data);
+	if( count($res) ) return TRUE;
 
-	    // there is guaranteed to be no more conditions of this type.
-	    break;
-	  }
+	// there is guaranteed to be no more conditions of this type.
+	break;
       }
+    }
 
     // this promotion is not dependant upon feu group membership.
     return FALSE;
@@ -209,34 +199,30 @@ class promo_tests
    */
   static public function single_product_from_hierarchy(&$promo,$product_id)
   {
-    $products = '';
-    for( $i = 0; $i < $promo->count_conditions(); $i++ )
-      {
-	$condition = $promo->get_condition($i);
-	switch( $condition->get_cond_type() )
-	  {
-	  case PROMOTIONS_COND_PRODHIER:
-	    $products = Products::GetProductIdsFromHierarchy($condition->get_data(),'.');
-	    $i = $promo->count_conditions();
-	    break;
+    $products = null;
+    for( $i = 0; $i < $promo->count_conditions(); $i++ ) {
+      $condition = $promo->get_condition($i);
+      switch( $condition->get_cond_type() ) {
+      case PROMOTIONS_COND_PRODHIER:
+	$products = Products::GetProductIdsFromHierarchy($condition->get_data(),'.');
+	$i = $promo->count_conditions();
+	break;
 
-	  default:
-	    continue;
-	    break;
-	  }
+      default:
+	continue;
+	break;
       }
+    }
 
     // check if there are products found
     if( !$products ) return FALSE; 
 
     // now check to see if the items in the cart match.
-    if( in_array($product_id,$products) )
-      {
-	return TRUE;
-      }
+    if( in_array($product_id,$products) ) {
+      return TRUE;
+    }
 
     return FALSE;
-
   }
 
 
@@ -252,35 +238,31 @@ class promo_tests
   static public function test_product_from_hierarchy($items,&$promo)
   {
     $products = '';
-    for( $i = 0; $i < $promo->count_conditions(); $i++ )
-      {
-	$condition = $promo->get_condition($i);
-	switch( $condition->get_cond_type() )
-	  {
-	  case PROMOTIONS_COND_PRODHIER:
-	    $products = Products::GetProductIdsFromHierarchy($condition->get_data(),'.');
-	    $i = $promo->count_conditions();
-	    break;
+    for( $i = 0; $i < $promo->count_conditions(); $i++ ) {
+      $condition = $promo->get_condition($i);
+      switch( $condition->get_cond_type() ) {
+      case PROMOTIONS_COND_PRODHIER:
+	$products = Products::GetProductIdsFromHierarchy($condition->get_data(),'.');
+	$i = $promo->count_conditions();
+	break;
 
-	  default:
-	    continue;
-	    break;
-	  }
+      default:
+	continue;
+	break;
       }
+    }
 
     // check if there are products found
     if( !$products ) return FALSE; 
 
     // now check to see if the items in the cart match.
-    for( $i = 0; $i < count($items); $i++ )
-      {
-	$item = $items[$i];
-	if( $item->get_item_type() == line_item::ITEMTYPE_PRODUCT && 
-	    in_array($item->get_item_id(),$products) )
-	  {
-	    return TRUE;
-	  }
+    for( $i = 0; $i < count($items); $i++ ) {
+      $item = $items[$i];
+      if( $item->get_item_type() == line_item::ITEMTYPE_PRODUCT && 
+	  in_array($item->get_item_id(),$products) ) {
+	return TRUE;
       }
+    }
 
     return FALSE;
   }
@@ -297,31 +279,28 @@ class promo_tests
   static public function single_product_from_category(&$promo,$product_id)
   {
     $products = '';
-    for( $i = 0; $i < $promo->count_conditions(); $i++ )
-      {
-	$condition = $promo->get_condition($i);
-	switch( $condition->get_cond_type() )
-	  {
-	  case PROMOTIONS_COND_PRODCAT:
-	    $products = Products::GetProductIdsFromCategories($condition->get_data());
-	    $i = $promo->count_conditions();
-	    break;
+    for( $i = 0; $i < $promo->count_conditions(); $i++ ) {
+      $condition = $promo->get_condition($i);
+      switch( $condition->get_cond_type() ) {
+      case PROMOTIONS_COND_PRODCAT:
+	$products = Products::GetProductIdsFromCategories($condition->get_data());
+	$i = $promo->count_conditions();
+	break;
 
-	  default:
-	    continue;
-	    break;
-	  }
+      default:
+	continue;
+	break;
       }
+    }
 
     // check if there are products found
     if( !$products ) return FALSE; 
 
     // now check to see if the product id matches.
     $item = $items[$i];
-    if( in_array($product_id,$products) )
-      {
-	return TRUE;
-      }
+    if( in_array($product_id,$products) ) {
+      return TRUE;
+    }
 
     return FALSE;
   }
@@ -339,35 +318,31 @@ class promo_tests
   static public function test_product_from_category($items,&$promo)
   {
     $products = '';
-    for( $i = 0; $i < $promo->count_conditions(); $i++ )
-      {
-	$condition = $promo->get_condition($i);
-	switch( $condition->get_cond_type() )
-	  {
-	  case PROMOTIONS_COND_PRODCAT:
-	    $products = Products::GetProductIdsFromCategories($condition->get_data());
-	    $i = $promo->count_conditions();
-	    break;
+    for( $i = 0; $i < $promo->count_conditions(); $i++ ) {
+      $condition = $promo->get_condition($i);
+      switch( $condition->get_cond_type() ) {
+      case PROMOTIONS_COND_PRODCAT:
+	$products = Products::GetProductIdsFromCategories($condition->get_data());
+	$i = $promo->count_conditions();
+	break;
 
-	  default:
-	    continue;
-	    break;
-	  }
+      default:
+	continue;
+	break;
       }
+    }
 
     // check if there are products found
     if( !$products ) return FALSE; 
 
     // now check to see if the items in the cart match.
-    for( $i = 0; $i < count($cart_items); $i++ )
-      {
-	$item = $items[$i];
-	if( $item->get_item_type == line_item::ITEMTYPE_PRODUCT && 
-	    in_array($item->get_item_id(),$products) )
-	  {
-	    return TRUE;
-	  }
+    for( $i = 0; $i < count($cart_items); $i++ ) {
+      $item = $items[$i];
+      if( $item->get_item_type == line_item::ITEMTYPE_PRODUCT && 
+	  in_array($item->get_item_id(),$products) ) {
+	return TRUE;
       }
+    }
 
     return FALSE;
   }
@@ -383,37 +358,33 @@ class promo_tests
    */
   static public function single_product_matches(&$promo,$product_id)
   {
-    $product = '';
-    for( $i = 0; $i < $promo->count_conditions(); $i++ )
-      {
-	$condition = $promo->get_condition($i);
-	switch( $condition->get_cond_type() )
-	  {
-	  case PROMOTIONS_COND_PRODID:
-	    $product = $condition->get_data();
-	    $i = $promo->count_conditions();
-	    break;
+    $product = null;
+    for( $i = 0; $i < $promo->count_conditions(); $i++ ) {
+      $condition = $promo->get_condition($i);
+      switch( $condition->get_cond_type() ) {
+      case PROMOTIONS_COND_PRODID:
+	$product = $condition->get_data();
+	$i = $promo->count_conditions();
+	break;
 
-	  default:
-	    continue;
-	    break;
-	  }
+      default:
+	continue;
+	break;
       }
+    }
 
     // check if there are products found
     if( !$product ) return FALSE; 
 
     $p_array = explode(',',$product);
-    for( $i = 0; $i < count($p_array); $i++ )
-    {
+    for( $i = 0; $i < count($p_array); $i++ ) {
       $p_array[$i] = (int)trim($p_array[$i]);
     }
 
     // now check to see if the items in the cart match.
-    if( in_array($product_id,$p_array) )
-      {
-	return TRUE;
-      }
+    if( in_array($product_id,$p_array) ) {
+      return TRUE;
+    }
 
     return FALSE;
   }
@@ -429,42 +400,37 @@ class promo_tests
    */
   static public function test_single_product($items,&$promo)
   {
-    $product = '';
-    for( $i = 0; $i < $promo->count_conditions(); $i++ )
-      {
-	$condition = $promo->get_condition($i);
-	switch( $condition->get_cond_type() )
-	  {
-	  case PROMOTIONS_COND_PRODID:
-	    $product = $condition->get_data();
-	    $i = $promo->count_conditions();
-	    break;
+    $product = null;
+    for( $i = 0; $i < $promo->count_conditions(); $i++ ) {
+      $condition = $promo->get_condition($i);
+      switch( $condition->get_cond_type() ) {
+      case PROMOTIONS_COND_PRODID:
+	$product = $condition->get_data();
+	$i = $promo->count_conditions();
+	break;
 
-	  default:
-	    continue;
-	    break;
-	  }
+      default:
+	continue;
+	break;
       }
+    }
 
     // check if there are products found
     if( !$product ) return FALSE; 
 
     $p_array = explode(',',$product);
-    for( $i = 0; $i < count($p_array); $i++ )
-    {
+    for( $i = 0; $i < count($p_array); $i++ ) {
       $p_array[$i] = (int)trim($p_array[$i]);
     }
 
     // now check to see if the items in the cart match.
-    for( $i = 0; $i < count($items); $i++ )
-      {
-	$item = $items[$i];
-	if( $item->get_item_type() == line_item::ITEMTYPE_PRODUCT && 
-            in_array($item->get_item_id(),$p_array) )
-	  {
-	    return TRUE;
-	  }
+    for( $i = 0; $i < count($items); $i++ ) {
+      $item = $items[$i];
+      if( $item->get_item_type() == line_item::ITEMTYPE_PRODUCT && 
+	  in_array($item->get_item_id(),$p_array) ) {
+	return TRUE;
       }
+    }
 
     return FALSE;
   }
@@ -473,4 +439,4 @@ class promo_tests
 #
 # EOF
 #
-?>
\ No newline at end of file
+?>
